diff --git a/arch/arm/mach-k3/j721e_init.c b/arch/arm/mach-k3/j721e_init.c
index c62932f6ff..6f324a23da 100644
--- a/arch/arm/mach-k3/j721e_init.c
+++ b/arch/arm/mach-k3/j721e_init.c
@@ -25,6 +25,10 @@
 #include <dm/root.h>
 #include "../../../board/ti/common/board_detect.h"
 
+#define GPU_HARDWARE_BASE_ADDRESS_READ  0x45DC5100
+#define GPU_HARDWARE_BASE_ADDRESS_WRITE 0x45DC5900
+#define REGISTER_VALUE_DISABLE_SNOOP    0x30000000
+
 #ifdef CONFIG_SPL_BUILD
 #ifdef CONFIG_K3_LOAD_SYSFW
 #ifdef CONFIG_TI_SECURE_DEVICE
@@ -96,6 +100,19 @@ static void ctrl_mmr_unlock(void)
 	mmr_unlock(CTRL_MMR0_BASE, 7);
 }
 
+static inline void _qos_work_around_for_gpu(phys_addr_t base)
+{
+	u32 offset;
+
+	for (offset = 0; offset < 8; offset++)
+		writel(REGISTER_VALUE_DISABLE_SNOOP, base + (offset * 4));
+}
+
+static void qos_work_around_for_gpu(void)
+{
+	_qos_work_around_for_gpu(GPU_HARDWARE_BASE_ADDRESS_READ);
+}
+
 #if defined(CONFIG_K3_LOAD_SYSFW)
 void k3_mmc_stop_clock(void)
 {
@@ -214,6 +231,7 @@ void board_init_f(ulong dummy)
 #ifdef CONFIG_CPU_V7R
 	disable_linefill_optimization();
 	setup_k3_mpu_regions();
+		qos_work_around_for_gpu();
 #endif
 
 	/* Init DM early */
